py-desmume
==========

|build| |docs| |pypi-version| |pypi-downloads| |pypi-license| |pypi-pyversions|

.. |build| image:: https://img.shields.io/github/workflow/status/SkyTemple/py-desmume/Build,%20test%20and%20publish
    :target: https://pypi.org/project/py-desmume/
    :alt: Build Status

.. |docs| image:: https://readthedocs.org/projects/py-desmume/badge/?version=latest
    :target: https://py-desmume.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |pypi-version| image:: https://img.shields.io/pypi/v/py-desmume
    :target: https://pypi.org/project/py-desmume/
    :alt: Version

.. |pypi-downloads| image:: https://img.shields.io/pypi/dm/py-desmume
    :target: https://pypi.org/project/py-desmume/
    :alt: Downloads

.. |pypi-license| image:: https://img.shields.io/pypi/l/py-desmume
    :alt: License (GPLv3)

.. |pypi-pyversions| image:: https://img.shields.io/pypi/pyversions/py-desmume
    :alt: Supported Python versions

A Python library for DeSmuME, the Nintendo DS library.

- Library to interface with a `DeSmuME fork`_ that has a binary interface.
- Reimplementation of the DeSmuME Glade-GTK UI with GTK3.

Running the setup.py (eg. via pip) compiles the library from the fork. Wheels are available
for Linux, Windows and MacOS.

Documentation can be found in the ``docs`` directory and at
https://py-desmume.readthedocs.org.

.. _DeSmuME fork: https://github.com/SkyTemple/desmume/tree/binary-interface
